pub struct WsAttachAlgoOrdParams {Show 13 fields
pub attach_algo_cl_ord_id: Option<String>,
pub sl_trigger_px: Option<String>,
pub sl_ord_px: Option<String>,
pub sl_trigger_px_type: Option<OKXTriggerType>,
pub tp_trigger_px: Option<String>,
pub tp_ord_px: Option<String>,
pub tp_trigger_px_type: Option<OKXTriggerType>,
pub callback_ratio: Option<String>,
pub callback_spread: Option<String>,
pub active_px: Option<String>,
pub new_callback_ratio: Option<String>,
pub new_callback_spread: Option<String>,
pub new_active_px: Option<String>,
}Expand description
Parameters for WebSocket place order operation.
Fields
attach_algo_cl_ord_id: Option<String>Attached algo client order ID.
sl_trigger_px: Option<String>Stop-loss trigger price.
sl_ord_px: Option<String>Stop-loss order price (-1 for market).
sl_trigger_px_type: Option<OKXTriggerType>Stop-loss trigger price type (last, mark, index).
tp_trigger_px: Option<String>Take-profit trigger price.
tp_ord_px: Option<String>Take-profit order price (-1 for market).
tp_trigger_px_type: Option<OKXTriggerType>Take-profit trigger price type (last, mark, index).
callback_ratio: Option<String>Callback ratio for attached trailing stop orders.
callback_spread: Option<String>Callback spread for attached trailing stop orders.
active_px: Option<String>Activation price for attached trailing stop orders.
new_callback_ratio: Option<String>New callback ratio for amended attached trailing stop orders.
new_callback_spread: Option<String>New callback spread for amended attached trailing stop orders.
new_active_px: Option<String>New activation price for amended attached trailing stop orders.