pub struct WsAttachAlgoOrdParamsBuilder { /* private fields */ }Expand description
Builder for WsAttachAlgoOrdParams.
Implementations
Sourceimpl WsAttachAlgoOrdParamsBuilder
impl WsAttachAlgoOrdParamsBuilder
Sourcepub fn attach_algo_cl_ord_id<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn attach_algo_cl_ord_id<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Attached algo client order ID.
Sourcepub fn sl_trigger_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn sl_trigger_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Stop-loss trigger price.
Sourcepub fn sl_ord_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn sl_ord_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Stop-loss order price (-1 for market).
Sourcepub fn sl_trigger_px_type<VALUE: Into<OKXTriggerType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn sl_trigger_px_type<VALUE: Into<OKXTriggerType>>( &mut self, value: VALUE, ) -> &mut Self
Stop-loss trigger price type (last, mark, index).
Sourcepub fn tp_trigger_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn tp_trigger_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Take-profit trigger price.
Sourcepub fn tp_ord_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn tp_ord_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Take-profit order price (-1 for market).
Sourcepub fn tp_trigger_px_type<VALUE: Into<OKXTriggerType>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn tp_trigger_px_type<VALUE: Into<OKXTriggerType>>( &mut self, value: VALUE, ) -> &mut Self
Take-profit trigger price type (last, mark, index).
Sourcepub fn callback_ratio<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn callback_ratio<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Callback ratio for attached trailing stop orders.
Sourcepub fn callback_spread<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn callback_spread<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
Callback spread for attached trailing stop orders.
Sourcepub fn active_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn active_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Activation price for attached trailing stop orders.
Sourcepub fn new_callback_ratio<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn new_callback_ratio<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
New callback ratio for amended attached trailing stop orders.
Sourcepub fn new_callback_spread<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn new_callback_spread<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
New callback spread for amended attached trailing stop orders.
Sourcepub fn new_active_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn new_active_px<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
New activation price for amended attached trailing stop orders.
Sourcepub fn build(
&self,
) -> Result<WsAttachAlgoOrdParams, WsAttachAlgoOrdParamsBuilderError>
pub fn build( &self, ) -> Result<WsAttachAlgoOrdParams, WsAttachAlgoOrdParamsBuilderError>